==> jc-1.4.0.tar.gz: polyglot/frontend/BarrierPass.h <==
// public class polyglot.frontend.BarrierPass

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class e0a64384fd8897ef polyglot_frontend_BarrierPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_BarrierPass_H_
#define _JC_polyglot_frontend_BarrierPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_BarrierPass$sub_refs	_jc_polyglot_frontend_BarrierPass$sub_refs;
typedef struct _jc_polyglot_frontend_BarrierPass$sub_nonrefs	_jc_polyglot_frontend_BarrierPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_BarrierPass$refs	_jc_polyglot_frontend_BarrierPass$refs;
typedef struct _jc_polyglot_frontend_BarrierPass$nonrefs	_jc_polyglot_frontend_BarrierPass$nonrefs;
typedef struct _jc_polyglot_frontend_BarrierPass$object	_jc_polyglot_frontend_BarrierPass$object;

typedef const struct _jc_polyglot_frontend_BarrierPass$vmethods	_jc_polyglot_frontend_BarrierPass$vmethods;
typedef const struct _jc_polyglot_frontend_BarrierPass$vtable	_jc_polyglot_frontend_BarrierPass$vtable;
typedef const struct _jc_polyglot_frontend_BarrierPass$vtype	_jc_polyglot_frontend_BarrierPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_BarrierPass$method$_init$21bc67ff6e7809cf(_jc_env *, struct _jc_polyglot_frontend_BarrierPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *);

// Virtual methods
extern jboolean _jc_polyglot_frontend_BarrierPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_BarrierPass$object *);

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_BarrierPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_BarrierPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_BarrierPass$object *);
};

// Vtable
struct _jc_polyglot_frontend_BarrierPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_BarrierPass$vmethods	polyglot_frontend_BarrierPass;
};

// Vtype
struct _jc_polyglot_frontend_BarrierPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_BarrierPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_BarrierPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_BarrierPass$refs {
    _jc_polyglot_frontend_BarrierPass$sub_refs	polyglot_frontend_BarrierPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_BarrierPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_BarrierPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_BarrierPass$sub_nonrefs	polyglot_frontend_BarrierPass;
};

// Object instance structure
struct _jc_polyglot_frontend_BarrierPass$object {
	_jc_polyglot_frontend_BarrierPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_BarrierPass$vtype	*vtype;
	_jc_polyglot_frontend_BarrierPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_BarrierPass$vtype _jc_polyglot_frontend_BarrierPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_BarrierPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_BarrierPass$class_object;

#endif	/* _JC_polyglot_frontend_BarrierPass_H_ */

==> jc-1.4.6.tar.gz: polyglot/frontend/BarrierPass.h <==
// public class polyglot.frontend.BarrierPass

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4dca5983f7072958 polyglot_frontend_AbstractPass
// @dep_class e0a64384fd8897ef polyglot_frontend_BarrierPass

// header file dependencies
// @dep_header polyglot_frontend_AbstractPass

#include "polyglot/frontend/AbstractPass.h"

#ifndef _JC_polyglot_frontend_BarrierPass_H_
#define _JC_polyglot_frontend_BarrierPass_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_polyglot_frontend_Job$object;
struct _jc_polyglot_frontend_Pass__24ID$object;

// Typedefs
typedef struct _jc_polyglot_frontend_BarrierPass$sub_refs	_jc_polyglot_frontend_BarrierPass$sub_refs;
typedef struct _jc_polyglot_frontend_BarrierPass$sub_nonrefs	_jc_polyglot_frontend_BarrierPass$sub_nonrefs;
typedef struct _jc_polyglot_frontend_BarrierPass$refs	_jc_polyglot_frontend_BarrierPass$refs;
typedef struct _jc_polyglot_frontend_BarrierPass$nonrefs	_jc_polyglot_frontend_BarrierPass$nonrefs;
typedef struct _jc_polyglot_frontend_BarrierPass$object	_jc_polyglot_frontend_BarrierPass$object;

typedef const struct _jc_polyglot_frontend_BarrierPass$vmethods	_jc_polyglot_frontend_BarrierPass$vmethods;
typedef const struct _jc_polyglot_frontend_BarrierPass$vtable	_jc_polyglot_frontend_BarrierPass$vtable;
typedef const struct _jc_polyglot_frontend_BarrierPass$vtype	_jc_polyglot_frontend_BarrierPass$vtype;

// Constructors
extern void _jc_polyglot_frontend_BarrierPass$method$_init$21bc67ff6e7809cf(_jc_env *, struct _jc_polyglot_frontend_BarrierPass$object *, struct _jc_polyglot_frontend_Pass__24ID$object *, struct _jc_polyglot_frontend_Job$object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_polyglot_frontend_BarrierPass$method$run$1ec62afce18bd5ee(_jc_env *, struct _jc_polyglot_frontend_BarrierPass$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_polyglot_frontend_BarrierPass$method_info$run$1ec62afce18bd5ee;

// Virtual methods structure
struct _jc_polyglot_frontend_BarrierPass$vmethods {
	jboolean	(*run$1ec62afce18bd5ee)(_jc_env *, struct _jc_polyglot_frontend_BarrierPass$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_polyglot_frontend_BarrierPass$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractPass$vmethods	polyglot_frontend_AbstractPass;
	_jc_polyglot_frontend_BarrierPass$vmethods	polyglot_frontend_BarrierPass;
};

// Vtype
struct _jc_polyglot_frontend_BarrierPass$vtype {
	_jc_type			type;
	_jc_polyglot_frontend_BarrierPass$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_frontend_BarrierPass$sub_refs {
	struct _jc_polyglot_frontend_Job$object	*job;
};

// Reference instance fields (object)
struct _jc_polyglot_frontend_BarrierPass$refs {
    _jc_polyglot_frontend_BarrierPass$sub_refs	polyglot_frontend_BarrierPass;
    _jc_polyglot_frontend_AbstractPass$sub_refs	polyglot_frontend_AbstractPass;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_frontend_BarrierPass$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_frontend_BarrierPass$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractPass$sub_nonrefs	polyglot_frontend_AbstractPass;
    _jc_polyglot_frontend_BarrierPass$sub_nonrefs	polyglot_frontend_BarrierPass;
};

// Object instance structure
struct _jc_polyglot_frontend_BarrierPass$object {
	_jc_polyglot_frontend_BarrierPass$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_frontend_BarrierPass$vtype	*vtype;
	_jc_polyglot_frontend_BarrierPass$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_frontend_BarrierPass$vtype _jc_polyglot_frontend_BarrierPass$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_frontend_BarrierPass, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_frontend_BarrierPass$class_object;

#endif	/* _JC_polyglot_frontend_BarrierPass_H_ */
